/*

The Life of a Geek
Copyright (C) 2003-2004 Daniel Quintiliani

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

You can e-mail Daniel Quintiliani at danq@danq.lunarpages.com

func.h: Commands and misc functions

11/26/04: Daniel Quintiliani <danq@danq.lunarpages.com>: Fixed inttostring() and
currencytostring().
8/2/04: Daniel Quintiliani <danq@danq.lunarpages.com>: Updated e-mail address
6/6/04: Daniel Quintiliani <coredump0@mercurylink.net>: Fixed pre-glibc-2.1
bugs.
4/1/04: Daniel Quintiliani <coredump0@mercurylink.net>: Added DeleteGame().
3/16/04: Daniel Quintiliani <coredump0@mercurylink.net>: Added SaveGame().
2/3/04: Daniel Quintiliani <coredump0@mercurylink.net>: Updated e-mail address,
added CalculateScore(), added DisplayScores(), added InsertScore(), updated
copyright.
7/4/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Added GenEnemy(),
updated readfromfilevars() for enemy computer, moved main.cc virus
deduction/healing code to DeductVirAndHeal(), updated CmdHack(), added
AttackEnemy(), added HackAntiVir(), updated CmdAntiVirus(), added
UploadVirus(), added LogOff(), moved truncf() and roundf() to strlwr.h,
added Victory().
6/14/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Fixed support for
older compilers/C libraries.
6/13/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Updated 
readfromfilevars(),
changed floattostring() to currencytostring(), added floattocurrency().
5/21/03: Daniel Quintiliani <coredump@coredumpcentral.org>: CmdWasteTime()
updated.
5/20/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Added 
readfromfilevars(), inttostring(), removed FuncGenGameName() and FuncGenEmu()
4/24/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Added readfromfile()
4/7/03: Daniel Quintiliani <coredump@coredumpcentral.org>: added
gpl_check_and_strlwr()

*/

#ifndef _FUNC_H
#define _FUNC_H

#include "version.h"

#if !defined _ISOC9X_SOURCE && !defined _ISOC99_SOURCE
#include "strlwr.h"
#else
#include <math.h>
#endif

#include <string>
#include "geek.h"
#include "comp.h"
#include "eltime.h"

using namespace std;

void CmdWasteTime(Geek &geek, Computer &comp, ElTime &elt); // Waste time
void CmdSpeedClass(Geek &geek, Computer &comp, ElTime &elt);
				// Take a speed class
void CmdWork(Geek &geek, Computer &comp, ElTime &elt); // Find a job.
void CmdBuyEnergyDrink(Geek &geek, ElTime &elt, int n); // Buy an energy drink.
void CmdDrinkEnergyDrink(Geek &geek, ElTime &elt); // Drink an energy drink.
int CmdHack(Geek &geek, Computer &comp, ElTime &elt); // Hack another geek.
						// Returns -1 if computer dead.
void CmdAntiVirus(Geek &geek, Computer &comp, ElTime &elt, float Cost);
					// Run anti-virus service.
void CmdSleep(Geek &geek, Computer &comp, ElTime &elt); // Sleep.

void FuncGenAttack(Computer &comp, int Percent); // Percent risk of attack
const char* gpl_check_and_strlwr(string& s); // Does gpl_check() and strlwr().
				      // Returns C string.
const char* readfromfile(const char* filename, const char* id, int newline);
			 // Reads and returns lines from file filename beginning
			//  with identifier id. If newline is zero, '\n' is
			// added at the end of each line.
const char* readfromfilevars(const char* filename, const char* id, int newline,
			Geek geek, Computer comp, Computer ecomp, ElTime elt, 
			int intvar, float floatvar, const char* cstrvar,
			const char* YInfected, const char* NInfected);
			// Same as above but used when variables are involved.
string inttostring(int n); // Converts n to string using ostringstream.
string currencytostring(float f); // Ditto, but with a float, formatted
					// like currency (two decimal places,
					// rounded to hundredths place)
float floattocurrency(float f); // Returns f rounded to hundredths place
Computer GenEnemy(Computer comp); // Generates an enemy Computer to crack 
                          	  // based on comp's properties. 
void AttackEnemy(Computer &ecomp); // Attack enemy computer.
int DeductVirAndHeal(Computer &comp, ElTime elt, int Main); 
				// Deducts points if infected.
				// If computer is main computer, Main is 0 and
				// code for main computer weaking is done,
				// otherwise enemy computer weakening is
				// done.
				// Returns -1 if you or computer dead.
void HackAntiVir(Geek &geek, Computer &comp);
void UploadVirus(Computer &ecomp); // Upload a virus to the enemy computer.
int LogOff(); // Logoff attempt. Returns 0 if successful.
void Victory(Geek &geek, Computer &comp, ElTime &elt, int Turns);
		// Generates a victory or arrest.
int CalculateScore(Geek geek, Computer comp, ElTime elt);
		// Calculates score, which is returned.
void DisplayScores(); // Displays scores in score file.
void InsertScore(Geek geek, Computer comp, ElTime elt);
void SaveGame(Geek geek, Computer comp, ElTime elt);
int LoadGame(Geek &geek, Computer &comp, ElTime &elt);
void DeleteGame();

#endif
